
// Le righe che terminano con //m sono traduzioni automatiche non verificate

Ls.ita = {
	"tt": "Italiano",

	"cols": {
		"c": "pulsanti azione",
		"dur": "durata",
		"q": "qualità / bitrate",
		"Ac": "codec audio",
		"Vc": "codec video",
		"Fmt": "formato / container",
		"Ahash": "checksum audio",
		"Vhash": "checksum video",
		"Res": "risoluzione",
		"T": "tipo file",
		"aq": "qualità audio / bitrate",
		"vq": "qualità video / bitrate",
		"pixfmt": "subsampling / struttura pixel",
		"resw": "risoluzione orizzontale",
		"resh": "risoluzione verticale",
		"chs": "canali audio",
		"hz": "frequenza di campionamento",
	},

	"hks": [
		[
			"varie",
			["ESC", "chiudi vari elementi"],

			"file-manager",
			["G", "alterna vista lista / griglia"],
			["T", "alterna miniature / icone"],
			["⇧ A/D", "dimensione miniature"],
			["ctrl-K", "elimina selezionati"],
			["ctrl-X", "taglia selezione negli appunti"],
			["ctrl-C", "copia selezione negli appunti"],
			["ctrl-V", "incolla (sposta/copia) qui"],
			["Y", "scarica selezionati"],
			["F2", "rinomina selezionati"],

			"file-list-sel",
			["spazio", "alterna selezione file"],
			["↑/↓", "sposta cursore selezione"],
			["ctrl ↑/↓", "sposta cursore e viewport"],
			["⇧ ↑/↓", "seleziona file prec/succ"],
			["ctrl-A", "seleziona tutti i file / cartelle"],
		], [
			"navigation",
			["B", "alterna breadcrumb / pannello nav"],
			["I/K", "cartella prec/succ"],
			["M", "cartella genitore (o comprimi corrente)"],
			["V", "alterna cartelle / file di testo nel pannello nav"],
			["A/D", "dimensione pannello nav"],
		], [
			"audio-player",
			["J/L", "brano prec/succ"],
			["U/O", "salta 10sec indietro/avanti"],
			["0..9", "salta a 0%..90%"],
			["P", "play/pausa (avvia anche)"],
			["S", "seleziona brano in riproduzione"],
			["Y", "scarica brano"],
		], [
			"image-viewer",
			["J/L, ←/→", "immagine prec/succ"],
			["Home/End", "prima/ultima immagine"],
			["F", "schermo intero"],
			["R", "ruota in senso orario"],
			["⇧ R", "ruota in senso antiorario"],
			["S", "seleziona immagine"],
			["Y", "scarica immagine"],
		], [
			"video.player",
			["U/O", "salta 10sec indietro/avanti"],
			["P/K/Spazio", "play/pausa"],
			["C", "continua riproduzione successivo"],
			["V", "loop"],
			["M", "muto"],
			["[ e ]", "imposta intervallo loop"],
		], [
			"textfile-viewer",
			["I/K", "file prec/succ"],
			["M", "chiudi file di testo"],
			["E", "modifica file di testo"],
			["S", "seleziona file (per taglia/copia/rinomina)"],
			["Y", "scarica il file di testo"], //m
			["⇧ J", "abbellire json"], //m
		]
	],

	"m_ok": "OK",
	"m_ng": "Annulla",

	"enable": "Abilita",
	"danger": "PERICOLO",
	"clipped": "copiato negli appunti",

	"ht_s1": "secondo",
	"ht_s2": "secondi",
	"ht_m1": "minuto",
	"ht_m2": "minuti",
	"ht_h1": "ora",
	"ht_h2": "ore",
	"ht_d1": "giorno",
	"ht_d2": "giorni",
	"ht_and": " e ",

	"goh": "control-panel",
	"gop": 'cartella sorella precedente">prec',
	"gou": 'cartella genitore">su',
	"gon": 'prossima cartella">succ',
	"logout": "Logout ",
	"login": "Accedi", //m
	"access": " accesso",
	"ot_close": "chiudi sottomenu",
	"ot_search": "`cerca file per attributi, percorso / nome, tag musicali, o qualsiasi combinazione di questi$N$N`foo bar` = deve contenere sia «foo» che «bar»,$N`foo -bar` = deve contenere «foo» ma non «bar»,$N`^yana .opus$` = inizia con «yana» ed è un file «opus»$N`&quot;try unite&quot;` = contiene esattamente «try unite»$N$Nil formato data è iso-8601, come$N`2009-12-31` o `2020-09-12 23:30:00`",
	"ot_unpost": "unpost: elimina i tuoi caricamenti recenti, o interrompi quelli non completati",
	"ot_bup": "bup: uploader di base, supporta anche netscape 4.0",
	"ot_mkdir": "mkdir: crea una nuova directory",
	"ot_md": "new-file: crea un nuovo file di testo", //m
	"ot_msg": "msg: invia un messaggio al log del server",
	"ot_mp": "opzioni lettore multimediale",
	"ot_cfg": "opzioni di configurazione",
	"ot_u2i": 'up2k: carica file (se hai accesso in scrittura) o attiva la modalità ricerca per vedere se esistono già da qualche parte sul server$N$NI caricamenti sono ripristinabili, multithreaded, e i timestamp dei file vengono preservati, ma usa più CPU di [🎈]&nbsp; (l\'uploader di base)<br /><br />durante i caricamenti, questa icona diventa un indicatore di progresso!',
	"ot_u2w": 'up2k: carica file con supporto per il ripristino (chiudi il browser e trascina gli stessi file più tardi)$N$NMultithreaded, e i timestamp dei file vengono preservati, ma usa più CPU di [🎈]&nbsp; (l\'uploader di base)<br /><br />durante i caricamenti, questa icona diventa un indicatore di progresso!',
	"ot_noie": 'Perfavore usa Chrome / Firefox / Edge',

	"ab_mkdir": "crea directory",
	"ab_mkdoc": "nuovo file di testo", //m
	"ab_msg": "invia msg al log srv",

	"ay_path": "salta alle cartelle",
	"ay_files": "salta ai file",

	"wt_ren": "rinomina elementi selezionati$NTasto rapido: F2",
	"wt_del": "elimina elementi selezionati$NTasto rapido: ctrl-K",
	"wt_cut": "taglia elementi selezionati &lt;small&gt;(poi incolla altrove)&lt;/small&gt;$NTasto rapido: ctrl-X",
	"wt_cpy": "copia elementi selezionati negli appunti$N(per incollarli altrove)$NTasto rapido: ctrl-C",
	"wt_pst": "incolla una selezione precedentemente tagliata / copiata$NTasto rapido: ctrl-V",
	"wt_selall": "seleziona tutti i file$NTasto rapido: ctrl-A (quando il file è focalizzato)",
	"wt_selinv": "inverti selezione",
	"wt_zip1": "scarica questa cartella come archivio",
	"wt_selzip": "scarica selezione come archivio",
	"wt_seldl": "scarica selezione come file separati$NTasto rapido: Y",
	"wt_npirc": "copia info traccia formato irc",
	"wt_nptxt": "copia info traccia testo semplice",
	"wt_m3ua": "aggiungi alla playlist m3u (clicca <code>📻copia</code> dopo)",
	"wt_m3uc": "copia playlist m3u negli appunti",
	"wt_grid": "alterna vista griglia / lista$NTasto rapido: G",
	"wt_prev": "traccia precedente$NTasto rapido: J",
	"wt_play": "play / pausa$NTasto rapido: P",
	"wt_next": "traccia successiva$NTasto rapido: L",

	"ul_par": "caricamenti paralleli:",
	"ut_rand": "randomizza nomi file",
	"ut_u2ts": "copia il timestamp di ultima modifica$Ndal tuo filesystem al server\">📅",
	"ut_ow": "sovrascrivere file esistenti sul server?$N🛡️: mai (genererà un nuovo nome file)$N🕒: sovrascrivi se il file del server è più vecchio del tuo$N♻️: sovrascrivi sempre se i file sono diversi$N⏭️: ignora sempre tutti i file esistenti", //m
	"ut_mt": "continua l'hashing di altri file durante il caricamento$N$NProva a disabilitare se la tua CPU o HDD è un collo di bottiglia",
	"ut_ask": 'chiedi conferma prima che inizi il caricamento">💭',
	"ut_pot": "migliora la velocità di caricamento su dispositivi lenti$Nrendendo l'interfaccia meno complessa",
	"ut_srch": "non caricare realmente, invece controlla se i file esistono già $N sul server (scansionerà tutte le cartelle che puoi leggere)",
	"ut_par": "metti in pausa i caricamenti impostandolo a 0$N$NAumenta se la tua connessione è lenta / alta latenza$N$NMantienilo a 1 su LAN o se l'HDD del server è un collo di bottiglia",
	"ul_btn": "trascina file / cartelle<br>qui (o cliccami)",
	"ul_btnu": "C A R I C A",
	"ul_btns": "C E R C A",

	"ul_hash": "hash",
	"ul_send": "invia",
	"ul_done": "fatto",
	"ul_idle1": "nessun caricamento ancora in coda",
	"ut_etah": "velocità media di &lt;em&gt;hashing&lt;/em&gt;, e tempo stimato al completamento",
	"ut_etau": "velocità media di &lt;em&gt;caricamento&lt;/em&gt; e tempo stimato al completamento",
	"ut_etat": "velocità &lt;em&gt;totale&lt;/em&gt; media e tempo stimato al completamento",

	"uct_ok": "completato con successo",
	"uct_ng": "non-valido: fallito / rifiutato / non-trovato",
	"uct_done": "ok e ng combinati",
	"uct_bz": "hashing o caricamento",
	"uct_q": "inattivo, in attesa",

	"utl_name": "nome file",
	"utl_ulist": "lista",
	"utl_ucopy": "copia",
	"utl_links": "link",
	"utl_stat": "stato",
	"utl_prog": "progresso",

	// keep short:
	"utl_404": "404",
	"utl_err": "ERRORE",
	"utl_oserr": "Errore-SO",
	"utl_found": "trovato",
	"utl_defer": "rinvia",
	"utl_yolo": "YOLO",
	"utl_done": "finito",

	"ul_flagblk": "i file sono stati aggiunti alla coda</b><br>tuttavia c'è un up2k occupato in un'altra scheda del browser,<br>quindi aspetto che quello finisca prima",
	"ul_btnlk": "la configurazione del server ha bloccato questo interruttore in questo stato",

	"udt_up": "Carica",
	"udt_srch": "Cerca",
	"udt_drop": "lascialo qui",

	"u_nav_m": '<h6>ok, cosa hai?</h6><code>Invio</code> = File (uno o più)\n<code>ESC</code> = Una cartella (incluse sottocartelle)',
	"u_nav_b": '<a href="#" id="modal-ok">File</a><a href="#" id="modal-ng">Una cartella</a>',

	"cl_opts": "opzioni",
	"cl_hfsz": "dimensione file", //m
	"cl_themes": "tema",
	"cl_langs": "lingua",
	"cl_ziptype": "download cartella",
	"cl_uopts": "opzioni up2k",
	"cl_favico": "favicon",
	"cl_bigdir": "cartelle grandi",
	"cl_hsort": "#ordinamento",
	"cl_keytype": "notazione tasti",
	"cl_hiddenc": "colonne nascoste",
	"cl_hidec": "nascondi",
	"cl_reset": "reset",
	"cl_hpick": "tocca le intestazioni delle colonne per nascondere nella tabella sottostante",
	"cl_hcancel": "nascondere colonne annullato",
	"cl_rcm": "menu contestuale", //m
	"cl_gauto": "auto田", //m

	"ct_grid": '田 griglia',
	"ct_ttips": '◔ ◡ ◔">ℹ️ tooltip',
	"ct_thumb": 'nella vista griglia, alterna icone o miniature$NTasto rapido: T">🖼️ miniature',
	"ct_csel": 'usa CTRL e SHIFT per la selezione file nella vista griglia">sel',
	"ct_dsel": 'usa la selezione tramite trascinamento nella vista griglia">trascina', //m
	"ct_dl": 'forza il download (non visualizzare inline) quando si clicca su un file">dl', //m
	"ct_ihop": 'quando il visualizzatore immagini è chiuso, scorri fino all\'ultimo file visualizzato">g⮯',
	"ct_dots": 'mostra file nascosti (se il server lo permette)">dotfile',
	"ct_qdel": 'quando elimini file, chiedi conferma solo una volta">qdel',
	"ct_dir1st": 'ordina cartelle prima dei file">📁 prima',
	"ct_nsort": 'ordinamento naturale (per nomi file con cifre iniziali)">nsort',
	"ct_utc": 'mostra tutte le date/ore in UTC">UTC',
	"ct_readme": 'mostra README.md negli elenchi cartelle">📜 readme',
	"ct_idxh": 'mostra index.html invece dell\'elenco cartelle">htm',
	"ct_sbars": 'mostra barre di scorrimento">⟊',

	"cut_umod": "se un file esiste già sul server, aggiorna il timestamp di ultima modifica del server per farlo coincidere con il tuo file locale (richiede permessi di scrittura+eliminazione)\">re📅",

	"cut_turbo": "il pulsante yolo, probabilmente NON lo vuoi abilitare:$N$NUsalo se stavi caricando una grande quantità di file e hai dovuto riavviare per qualche motivo, e vuoi continuare il caricamento il prima possibile$N$NQuesto sostituisce il controllo hash con un semplice <em>&quot;questo ha la stessa dimensione file sul server?&quot;</em> quindi se il contenuto del file è diverso NON verrà caricato$N$NDovresti spegnere questo quando il caricamento è finito, e poi &quot;caricare&quot; di nuovo gli stessi file per far verificare al client\">turbo",

	"cut_datechk": "non ha effetto a meno che il pulsante turbo sia abilitato$N$NRiduce il fattore yolo di una piccola quantità; controlla se i timestamp dei file sul server corrispondono ai tuoi$N$NDovrebbe <em>teoricamente</em> catturare la maggior parte dei caricamenti non finiti / corrotti, ma non è un sostituto per fare un passaggio di verifica con turbo disabilitato dopo\">date-chk",

	"cut_u2sz": "dimensione (in MiB) di ogni chunk di caricamento; valori grandi volano meglio attraverso l'atlantico. Prova valori bassi su connessioni molto inaffidabili",

	"cut_flag": "assicura che solo una scheda stia caricando alla volta $N -- anche le altre schede devono avere questo abilitato $N -- influisce solo sulle schede dello stesso dominio",

	"cut_az": "carica file in ordine alfabetico, invece che dal file più piccolo prima$N$NL'ordine alfabetico può rendere più facile controllare a occhio se qualcosa è andato storto sul server, ma rende il caricamento leggermente più lento su fibra / LAN",

	"cut_nag": "notifica SO quando il caricamento si completa$N(solo se il browser o la scheda non è attiva)",
	"cut_sfx": "allarme sonoro quando il caricamento si completa$N(solo se il browser o la scheda non è attiva)",

	"cut_mt": "usa multithreading per accelerare l'hashing dei file$N$NQuesto usa web-worker e richiede$Npiù RAM (fino a 512 MiB extra)$N$NRende https 30% più veloce, http 4.5x più veloce\">mt",

	"cut_wasm": "usa wasm invece dell'hasher integrato del browser; migliora la velocità sui browser basati su chrome ma aumenta il carico CPU, e molte versioni vecchie di chrome hanno bug che fanno consumare tutta la RAM al browser e crashare se questo è abilitato\">wasm",

	"cft_text": "testo favicon (vuoto e aggiorna per disabilitare)",
	"cft_fg": "colore primo piano",
	"cft_bg": "colore sfondo",

	"cdt_lim": "numero massimo di file da mostrare in una cartella",
	"cdt_ask": "quando scorri verso il fondo,$Ninvece di caricare più file,$Nchiedi cosa fare",
	"cdt_hsort": "`quante regole di ordinamento (`,sorthref`) includere negli URL multimediali. Impostandolo a 0 ignorerà anche le regole di ordinamento incluse nei link multimediali quando li clicchi",
	"cdt_ren": "abilita il menu contestuale personalizzato, il menu normale è accessibile con shift + clic destro\">abilita", //m
	"cdt_rdb": "mostra il menu normale con il tasto destro quando quello personalizzato è già aperto e si clicca di nuovo\">x2", //m

	"tt_entree": "mostra pannello nav (barra laterale albero directory)$NTasto rapido: B",
	"tt_detree": "mostra breadcrumb$NTasto rapido: B",
	"tt_visdir": "scorri alla cartella selezionata",
	"tt_ftree": "alterna albero cartelle / file di testo$NTasto rapido: V",
	"tt_pdock": "mostra cartelle genitore in un pannello ancorato in alto",
	"tt_dynt": "crescita automatica mentre l'albero si espande",
	"tt_wrap": "a capo parola",
	"tt_hover": "rivela righe che traboccano al passaggio del mouse$N( interrompe lo scorrimento a meno che il cursore $N&nbsp; del mouse non sia nella grondaia sinistra )",
	"tt_gauto": "mostra come griglia o lista in base al contenuto della cartella", //m
	"tt_gathr": "usa la griglia se questa percentuale di file sono immagini/video", //m

	"ml_pmode": "alla fine della cartella...",
	"ml_btns": "comandi",
	"ml_tcode": "transcodifica",
	"ml_tcode2": "transcodifica in",
	"ml_tint": "tinta",
	"ml_eq": "equalizzatore audio",
	"ml_drc": "compressore gamma dinamica",
	"ml_ss": "salta i silenzi", //m

	"mt_loop": "loop/ripeti una canzone\">🔁",
	"mt_one": "fermati dopo una canzone\">1️⃣",
	"mt_shuf": "mescola le canzoni in ogni cartella\">🔀",
	"mt_aplay": "autoplay se c'è un song-ID nel link che hai cliccato per accedere al server$N$NDisabilitando questo fermerà anche l'aggiornamento dell'URL della pagina con song-ID quando riproduci musica, per prevenire autoplay se queste impostazioni vengono perse ma l'URL rimane\">a▶",
	"mt_preload": "inizia a caricare la prossima canzone verso la fine per riproduzione senza interruzioni\">preload",
	"mt_prescan": "vai alla prossima cartella prima che finisca l'ultima canzone$Nmantenendo felice il browser web$Ncosì non si ferma la riproduzione\">nav",
	"mt_fullpre": "prova a precaricare l'intera canzone;$N✅ abilita su connessioni <b>inaffidabili</b>,$N❌ <b>disabilita</b> su connessioni lente probabilmente\">full",
	"mt_fau": "sui telefoni, previeni che la musica si fermi se la prossima canzone non si precarica abbastanza velocemente (può rendere glitchy la visualizzazione dei tag)\">☕️",
	"mt_waves": "barra di ricerca forma d'onda:$Nmostra ampiezza audio nello scrubber\">~s",
	"mt_npclip": "mostra pulsanti per copiare negli appunti la canzone attualmente in riproduzione\">/np",
	"mt_m3u_c": "mostra pulsanti per copiare negli appunti le$Ncanzoni selezionate come voci playlist m3u8\">📻",
	"mt_octl": "integrazione so (tasti multimediali / osd)\">os-ctl",
	"mt_oseek": "permetti ricerca attraverso integrazione so$N$Nnota: su alcuni dispositivi (iPhone),$Nquesto sostituisce il pulsante canzone successiva\">seek",
	"mt_oscv": "mostra copertina album in osd\">art",
	"mt_follow": "mantieni la traccia in riproduzione scorrevole nella vista\">🎯",
	"mt_compact": "controlli compatti\">⟎",
	"mt_uncache": "pulisci cache &nbsp;(prova ad attivare se il tuo browser ha messo in cache$Nuna copia rotta di una canzone e si rifiuta di riprodurla)\">uncache",
	"mt_mloop": "loop della cartella aperta\">🔁 loop",
	"mt_mnext": "carica la prossima cartella e continua\">📂 succ",
	"mt_mstop": "ferma riproduzione\">⏸ stop",
	"mt_cflac": "converti flac / wav in {0}\">flac",
	"mt_caac": "converti aac / m4a in {0}\">aac",
	"mt_coth": "converti tutti gli altri (non mp3) in {0}\">oth",
	"mt_c2opus": "scelta migliore per desktop, laptop, android\">opus",
	"mt_c2owa": "opus-weba, per iOS 17.5 e più recenti\">owa",
	"mt_c2caf": "opus-caf, per iOS 11 fino a 17\">caf",
	"mt_c2mp3": "usa questo su dispositivi molto vecchi\">mp3",
	"mt_c2flac": "qualità audio migliore, ma download pesanti\">flac", //m
	"mt_c2wav": "riproduzione non compressa (ancora più grande)\">wav", //m
	"mt_c2ok": "bene, buona scelta",
	"mt_c2nd": "quello non è il formato di output raccomandato per il tuo dispositivo, ma va bene",
	"mt_c2ng": "il tuo dispositivo non sembra supportare questo formato di output, ma proviamo comunque",
	"mt_xowa": "ci sono bug in iOS che prevengono la riproduzione in background usando questo formato; usa caf o mp3 invece",
	"mt_tint": "livello sfondo (0-100) sulla barra di ricerca$Nper rendere il buffering meno distraente",
	"mt_eq": "`abilita l'equalizzatore e controllo guadagno;$N$Nboost `0` = volume standard 100% (non modificato)$N$Nwidth `1 &nbsp;` = stereo standard (non modificato)$Nwidth `0.5` = 50% crossfeed sinistra-destra$Nwidth `0 &nbsp;` = mono$N$Nboost `-0.8` &amp; width `10` = rimozione vocale :^)$N$Nabilitando l'equalizzatore rende gli album senza interruzioni completamente senza interruzioni, quindi lascialo acceso con tutti i valori a zero (eccetto width = 1) se ti importa di quello",
	"mt_drc": "abilita il compressore gamma dinamica (appiattitore volume / brickwaller); abiliterà anche EQ per bilanciare gli spaghetti, quindi imposta tutti i campi EQ eccetto 'width' a 0 se non lo vuoi$N$NAbbassa il volume dell'audio sopra THRESHOLD dB; per ogni RATIO dB oltre THRESHOLD c'è 1 dB di output, quindi i valori di default di tresh -24 e ratio 12 significa che non dovrebbe mai diventare più forte di -22 dB ed è sicuro aumentare il boost equalizzatore a 0.8, o anche 1.8 con ATK 0 e un RLS enorme come 90 (funziona solo in firefox; RLS è max 1 in altri browser)$N$N(vedi wikipedia, lo spiegano molto meglio)",
	"mt_ss": "`abilita il salto del silenzio; moltiplica la velocità di riproduzione per `av` vicino a inizio/fine quando il volume è sotto `vol` e la posizione è nei primi `ini`% o ultimi `fin`%", //m
	"mt_ssvt": "soglia volume (0-255)\">vol", //m
	"mt_ssts": "soglia attiva (% traccia, inizio)\">ini", //m
	"mt_sste": "soglia attiva (% traccia, fine)\">fin", //m
	"mt_sssm": "moltiplicatore velocità riproduzione\">av", //m

	"mb_play": "riproduci",
	"mm_hashplay": "riprodurre questo file audio?",
	"mm_m3u": "premi <code>Invio/OK</code> per Riprodurre\npremi <code>ESC/Annulla</code> per Modificare",
	"mp_breq": "serve firefox 82+ o chrome 73+ o iOS 15+",
	"mm_bload": "ora caricando...",
	"mm_bconv": "convertendo in {0}, attendi...",
	"mm_opusen": "il tuo browser non può riprodurre file aac / m4a;\ntranscodifica in opus ora abilitata",
	"mm_playerr": "riproduzione fallita: ",
	"mm_eabrt": "Il tentativo di riproduzione è stato cancellato",
	"mm_enet": "La tua connessione internet è instabile",
	"mm_edec": "Questo file è presumibilmente corrotto??",
	"mm_esupp": "Il tuo browser non capisce questo formato audio",
	"mm_eunk": "Errore Sconosciuto",
	"mm_e404": "Non è stato possibile riprodurre audio; errore 404: File non trovato.",
	"mm_e403": "Non è stato possibile riprodurre audio; errore 403: Accesso negato.\n\nProva a premere F5 per ricaricare, forse sei stato disconnesso",
	"mm_e415": "Non è stato possibile riprodurre audio; errore 415: Conversione del file non riuscita; controlla i log del server.", //m
	"mm_e500": "Non è stato possibile riprodurre audio; errore 500: Controlla i log del server.",
	"mm_e5xx": "Non è stato possibile riprodurre audio; errore server ",
	"mm_nof": "non trovo altri file audio nelle vicinanze",
	"mm_prescan": "Cercando musica da riprodurre dopo...",
	"mm_scank": "Trovata la prossima canzone:",
	"mm_uncache": "cache pulita; tutte le canzoni si riscaricheranno alla prossima riproduzione",
	"mm_hnf": "quella canzone non esiste più",

	"im_hnf": "quell'immagine non esiste più",

	"f_empty": 'questa cartella è vuota',
	"f_chide": 'questo nasconderà la colonna «{0}»\n\npuoi mostrare le colonne nella scheda impostazioni',
	"f_bigtxt": "questo file è {0} MiB grande -- visualizzare davvero come testo?",
	"f_bigtxt2": "visualizzare solo la fine del file invece? questo abiliterà anche following/tailing, mostrando righe di testo appena aggiunte in tempo reale",
	"fbd_more": '<div id="blazy">mostrando <code>{0}</code> di <code>{1}</code> file; <a href="#" id="bd_more">mostra {2}</a> o <a href="#" id="bd_all">mostra tutti</a></div>',
	"fbd_all": '<div id="blazy">mostrando <code>{0}</code> di <code>{1}</code> file; <a href="#" id="bd_all">mostra tutti</a></div>',
	"f_anota": "solo {0} dei {1} elementi sono stati selezionati;\nper selezionare l'intera cartella, prima scorri fino in fondo",

	"f_dls": 'i link dei file nella cartella corrente sono stati\ncambiati in link di download',
	"f_dl_nd": 'cartella ignorata (usa invece il download zip/tar):\n', //m

	"f_partial": "Per scaricare in sicurezza un file che è attualmente in fase di caricamento, clicca il file che ha lo stesso nome, ma senza l'estensione <code>.PARTIAL</code>. Premi ANNULLA o Escape per farlo.\n\nPremendo OK / Invio ignorerai questo avviso e continuerai a scaricare il file <code>.PARTIAL</code> scratch, che quasi sicuramente ti darà dati corrotti.",

	"ft_paste": "incolla {0} elementi$NTasto rapido: ctrl-V",
	"fr_eperm": 'impossibile rinominare:\nnon hai il permesso “sposta” in questa cartella',
	"fd_eperm": 'impossibile eliminare:\nnon hai il permesso “elimina” in questa cartella',
	"fc_eperm": 'impossibile tagliare:\nnon hai il permesso “sposta” in questa cartella',
	"fp_eperm": 'impossibile incollare:\nnon hai il permesso “scrivi” in questa cartella',
	"fr_emore": "seleziona almeno un elemento da rinominare",
	"fd_emore": "seleziona almeno un elemento da eliminare",
	"fc_emore": "seleziona almeno un elemento da tagliare",
	"fcp_emore": "seleziona almeno un elemento da copiare negli appunti",

	"fs_sc": "condividi la cartella in cui ti trovi",
	"fs_ss": "condividi i file selezionati",
	"fs_just1d": "non puoi selezionare più di una cartella,\no mescolare file e cartelle in una selezione",
	"fs_abrt": "❌ interrompi",
	"fs_rand": "🎲 nome.casuale",
	"fs_go": "✅ crea condivisione",
	"fs_name": "nome",
	"fs_src": "sorgente",
	"fs_pwd": "password",
	"fs_exp": "scadenza",
	"fs_tmin": "min",
	"fs_thrs": "ore",
	"fs_tdays": "giorni",
	"fs_never": "eterno",
	"fs_pname": "nome link opzionale; sarà casuale se vuoto",
	"fs_tsrc": "il file o cartella da condividere",
	"fs_ppwd": "password opzionale",
	"fs_w8": "creando condivisione...",
	"fs_ok": "premi <code>Invio/OK</code> per Appunti\npremi <code>ESC/Annulla</code> per Chiudere",

	"frt_dec": "può risolvere alcuni casi di nomi file corrotti\">url-decode",
	"frt_rst": "ripristina nomi file modificati a quelli originali\">↺ reset",
	"frt_abrt": "interrompi e chiudi questa finestra\">❌ annulla",
	"frb_apply": "APPLICA RINOMINA",
	"fr_adv": "rinomina batch / metadata / pattern\">avanzato",
	"fr_case": "regex case-sensitive\">maiusc",
	"fr_win": "nomi sicuri per windows; sostituisce <code>&lt;&gt;:&quot;\\|?*</code> con caratteri giapponesi fullwidth\">win",
	"fr_slash": "sostituisce <code>/</code> con un carattere che non causa la creazione di nuove cartelle\">no /",
	"fr_re": "`pattern di ricerca regex da applicare ai nomi file originali; i gruppi di cattura possono essere referenziati nel campo formato sottostante come `(1)` e `(2)` e così via",
	"fr_fmt": "`ispirato da foobar2000:$N`(title)` è sostituito dal titolo della canzone,$N`[(artist) - ](title)` salta [questa] parte se artista è vuoto$N`$lpad((tn),2,0)` aggiunge padding al numero traccia a 2 cifre",
	"fr_pdel": "elimina",
	"fr_pnew": "salva come",
	"fr_pname": "fornisci un nome per il tuo nuovo preset",
	"fr_aborted": "interrotto",
	"fr_lold": "nome vecchio",
	"fr_lnew": "nome nuovo",
	"fr_tags": "tag per i file selezionati (sola lettura, solo per riferimento):",
	"fr_busy": "rinominando {0} elementi...\n\n{1}",
	"fr_efail": "rinomina fallita:\n",
	"fr_nchg": "{0} dei nuovi nomi sono stati alterati a causa di <code>win</code> e/o <code>no /</code>\n\nOK per continuare con questi nuovi nomi alterati?",

	"fd_ok": "eliminazione OK",
	"fd_err": "eliminazione fallita:\n",
	"fd_none": "niente è stato eliminato; forse bloccato dalla configurazione server (xbd)?",
	"fd_busy": "eliminando {0} elementi...\n\n{1}",
	"fd_warn1": "ELIMINARE questi {0} elementi?",
	"fd_warn2": "<b>Ultima possibilità!</b> Nessun modo per annullare. Eliminare?",

	"fc_ok": "tagliati {0} elementi",
	"fc_warn": 'tagliati {0} elementi\n\nma: solo <b>questa</b> scheda-browser può incollarli\n(dato che la selezione è così assolutamente massiva)',

	"fcc_ok": "copiati {0} elementi negli appunti",
	"fcc_warn": 'copiati {0} elementi negli appunti\n\nma: solo <b>questa</b> scheda-browser può incollarli\n(dato che la selezione è così assolutamente massiva)',

	"fp_apply": "usa questi nomi",
	"fp_skip": "salta conflitti", //m
	"fp_ecut": "prima taglia o copia alcuni file / cartelle da incollare / spostare\n\nnota: puoi tagliare / incollare attraverso diverse schede del browser",
	"fp_ename": "{0} elementi non possono essere spostati qui perché i nomi sono già presi. Dai loro nuovi nomi qui sotto per continuare, o lascia vuoto il nome (\"salta conflitti\") per saltarli:", //m
	"fcp_ename": "{0} elementi non possono essere copiati qui perché i nomi sono già presi. Dai loro nuovi nomi qui sotto per continuare, o lascia vuoto il nome (\"salta conflitti\") per saltarli:", //m
	"fp_emore": "ci sono ancora alcune collisioni di nomi file rimaste da risolvere",
	"fp_ok": "spostamento OK",
	"fcp_ok": "copia OK",
	"fp_busy": "spostando {0} elementi...\n\n{1}",
	"fcp_busy": "copiando {0} elementi...\n\n{1}",
	"fp_abrt": "annullamento in corso...", //m
	"fp_err": "spostamento fallito:\n",
	"fcp_err": "copia fallita:\n",
	"fp_confirm": "spostare questi {0} elementi qui?",
	"fcp_confirm": "copiare questi {0} elementi qui?",
	"fp_etab": 'fallito leggere appunti da altra scheda browser',
	"fp_name": "caricando un file dal tuo dispositivo. Dagli un nome:",
	"fp_both_m": '<h6>scegli cosa incollare</h6><code>Invio</code> = Sposta {0} file da «{1}»\n<code>ESC</code> = Carica {2} file dal tuo dispositivo',
	"fcp_both_m": '<h6>scegli cosa incollare</h6><code>Invio</code> = Copia {0} file da «{1}»\n<code>ESC</code> = Carica {2} file dal tuo dispositivo',
	"fp_both_b": '<a href="#" id="modal-ok">Sposta</a><a href="#" id="modal-ng">Carica</a>',
	"fcp_both_b": '<a href="#" id="modal-ok">Copia</a><a href="#" id="modal-ng">Carica</a>',

	"mk_noname": "scrivi un nome nel campo di testo a sinistra prima di farlo :p",
	"nmd_i1": "puoi anche aggiungere l’estensione che vuoi, per esempio <code>.md</code>", //m
	"nmd_i2": "puoi creare solo file <code>.{0}</code> perché non hai il permesso di eliminare", //m

	"tv_load": "Caricando documento di testo:\n\n{0}\n\n{1}% ({2} di {3} MiB caricati)",
	"tv_xe1": "impossibile caricare file di testo:\n\nerrore ",
	"tv_xe2": "404, file non trovato",
	"tv_lst": "lista di file di testo in",
	"tvt_close": "torna alla vista cartella$NTasto rapido: M (o Esc)\">❌ chiudi",
	"tvt_dl": "scarica questo file$NTasto rapido: Y\">💾 scarica",
	"tvt_prev": "mostra documento precedente$NTasto rapido: i\">⬆ prec",
	"tvt_next": "mostra documento successivo$NTasto rapido: K\">⬇ succ",
	"tvt_sel": "seleziona file &nbsp; ( per taglia / copia / elimina / ... )$NTasto rapido: S\">sel",
	"tvt_j": "abbellire json$NTasto rapido: shift-J\">j", //m
	"tvt_edit": "apri file nell'editor di testo$NTasto rapido: E\">✏️ modifica",
	"tvt_tail": "monitora file per cambiamenti; mostra nuove righe in tempo reale\">📡 segui",
	"tvt_wrap": "a capo parola\">↵",
	"tvt_atail": "blocca scorrimento in fondo alla pagina\">⚓",
	"tvt_ctail": "decodifica colori terminale (codici escape ansi)\">🌈",
	"tvt_ntail": "limite scrollback (quanti byte di testo mantenere caricati)",

	"m3u_add1": "canzone aggiunta alla playlist m3u",
	"m3u_addn": "{0} canzoni aggiunte alla playlist m3u",
	"m3u_clip": "playlist m3u ora copiata negli appunti\n\ndovresti creare un nuovo file di testo chiamato qualcosa.m3u e incollare la playlist in quel documento; questo la renderà riproducibile",

	"gt_vau": "non mostrare video, riproduci solo l'audio\">🎧",
	"gt_msel": "abilita selezione file; ctrl-click un file per sovrascrivere$N$N&lt;em&gt;quando attivo: doppio-click un file / cartella per aprirlo&lt;/em&gt;$N$NTasto rapido: S\">multiselezione",
	"gt_crop": "ritaglia miniature al centro\">ritaglia",
	"gt_3x": "miniature hi-res\">3x",
	"gt_zoom": "zoom",
	"gt_chop": "taglia",
	"gt_sort": "ordina per",
	"gt_name": "nome",
	"gt_sz": "dimensione",
	"gt_ts": "data",
	"gt_ext": "tipo",
	"gt_c1": "tronca nomi file di più (mostra meno)",
	"gt_c2": "tronca nomi file di meno (mostra di più)",

	"sm_w8": "cercando...",
	"sm_prev": "i risultati di ricerca qui sotto sono da una query precedente:\n  ",
	"sl_close": "chiudi risultati ricerca",
	"sl_hits": "mostrando {0} risultati",
	"sl_moar": "carica altro",

	"s_sz": "dimensione",
	"s_dt": "data",
	"s_rd": "percorso",
	"s_fn": "nome",
	"s_ta": "tag",
	"s_ua": "car@",
	"s_ad": "avanz.",
	"s_s1": "MiB minimo",
	"s_s2": "MiB massimo",
	"s_d1": "iso8601 min.",
	"s_d2": "iso8601 max.",
	"s_u1": "caricato dopo",
	"s_u2": "e/o prima",
	"s_r1": "percorso contiene &nbsp; (separato da spazi)",
	"s_f1": "nome contiene &nbsp; (nega con -nope)",
	"s_t1": "tag contiene &nbsp; (^=inizio, fine=$)",
	"s_a1": "proprietà metadata specifiche",

	"md_eshow": "impossibile renderizzare ",
	"md_off": "[📜<em>readme</em>] disabilitato in [⚙️] -- documento nascosto",

	"badreply": "Fallito nel parsare risposta dal server",

	"xhr403": "403: Accesso negato\n\nprova a premere F5, forse sei stato disconnesso",
	"xhr0": "sconosciuto (probabilmente persa connessione al server, o server offline)",
	"cf_ok": "scusa per quello -- la protezione DD" + wah + "oS è entrata in azione\n\nle cose dovrebbero riprendere in circa 30 sec\n\nse non succede niente, premi F5 per ricaricare la pagina",
	"tl_xe1": "impossibile elencare sottocartelle:\n\nerrore ",
	"tl_xe2": "404: Cartella non trovata",
	"fl_xe1": "impossibile elencare file nella cartella:\n\nerrore ",
	"fl_xe2": "404: Cartella non trovata",
	"fd_xe1": "impossibile creare sottocartella:\n\nerrore ",
	"fd_xe2": "404: Cartella genitore non trovata",
	"fsm_xe1": "impossibile inviare messaggio:\n\nerrore ",
	"fsm_xe2": "404: Cartella genitore non trovata",
	"fu_xe1": "fcaricamento fallito per la lista unpost dal server:\n\nerrore ",
	"fu_xe2": "404: File non trovato??",

	"fz_tar": "file gnu-tar non compresso (linux / mac)",
	"fz_pax": "tar formato pax non compresso (più lento)",
	"fz_targz": "gnu-tar con compressione gzip livello 3$N$NSolitamente è molto lento, quindi$Nusa tar non compresso",
	"fz_tarxz": "gnu-tar con compressione xz livello 1$N$NQuesto è solitamente molto lento, quindi$Nusa tar non compresso",
	"fz_zip8": "zip con nomi file utf8 (forse instabile su windows 7 e precedenti)",
	"fz_zipd": "zip con nomi file cp437 tradizionali, per software molto vecchio",
	"fz_zipc": "cp437 con crc32 calcolato presto,$Nper MS-DOS PKZIP v2.04g (ottobre 1993)$N(ci vuole più tempo per elaborare prima che possa iniziare il download)",

	"un_m1": "puoi eliminare i tuoi caricamenti recenti (o interrompere quelli non finiti) qui sotto",
	"un_upd": "aggiorna",
	"un_m4": "o condividi i file visibili qui sotto:",
	"un_ulist": "mostra",
	"un_ucopy": "copia",
	"un_flt": "filtro opzionale:&nbsp; URL deve contenere",
	"un_fclr": "resetta filtro",
	"un_derr": 'unpost-delete fallito:\n',
	"un_f5": 'qualcosa si è rotto, prova un aggiornamento o premi F5',
	"un_uf5": "scusa ma devi aggiornare la pagina (per esempio premendo F5 o CTRL-R) prima che questo caricamento possa essere interrotto",
	"un_nou": '<b>avviso:</b> server troppo occupato per mostrare caricamenti non finiti; clicca il link "aggiorna" tra un po\'',
	"un_noc": '<b>avviso:</b> unpost di file completamente caricati non è abilitato/permesso nella configurazione server',
	"un_max": "mostrando primi 2000 file (usa il filtro)",
	"un_avail": "{0} caricamenti recenti possono essere eliminati<br />{1} non finiti possono essere interrotti",
	"un_m2": "ordinati per tempo di caricamento; più recenti prima:",
	"un_no1": "scherzo! nessun caricamento è abbastanza recente",
	"un_no2": "scherzo! nessun caricamento che corrisponde a quel filtro è abbastanza recente",
	"un_next": "elimina i prossimi {0} file qui sotto",
	"un_abrt": "interrompi",
	"un_del": "elimina",
	"un_m3": "caricando i tuoi caricamenti recenti...",
	"un_busy": "eliminando {0} file...",
	"un_clip": "{0} link copiati negli appunti",

	"u_https1": "dovresti",
	"u_https2": "passare a https",
	"u_https3": "per prestazioni migliori",
	"u_ancient": 'il tuo browser è incredibilmente antico -- forse dovresti <a href="#" onclick="goto(\'bup\')">usare bup invece</a>',
	"u_nowork": "serve firefox 53+ o chrome 57+ o iOS 11+",
	"tail_2old": "serve firefox 105+ o chrome 71+ o iOS 14.5+",
	"u_nodrop": 'il tuo browser è troppo vecchio per il caricamento drag-and-drop',
	"u_notdir": "quella non è una cartella!\n\nil tuo browser è troppo vecchio,\nprova dragdrop invece",
	"u_uri": "per trascinare immagini da altre finestre del browser,\nrilasciale sul pulsante upload grande",
	"u_enpot": 'passa alla <a href="#">UI patata</a> (può migliorare velocità upload)',
	"u_depot": 'passa alla <a href="#">UI elegante</a> (può ridurre velocità upload)',
	"u_gotpot": 'passando alla UI patata per migliorare velocità upload,\n\nsentiti libero di non essere d\'accordo e tornare indietro!',
	"u_pott": "<p>file: &nbsp; <b>{0}</b> finiti, &nbsp; <b>{1}</b> falliti, &nbsp; <b>{2}</b> occupati, &nbsp; <b>{3}</b> in coda</p>",
	"u_ever": "questo è l'uploader di base; up2k necessita almeno<br>chrome 21 // firefox 13 // edge 12 // opera 12 // safari 5.1",
	"u_su2k": 'questo è l\'uploader di base; <a href="#" id="u2yea">up2k</a> è migliore',
	"u_uput": 'velocizza (salta checksum)',
	"u_ewrite": 'non hai accesso in scrittura a questa cartella',
	"u_eread": 'non hai accesso in lettura a questa cartella',
	"u_enoi": 'file-search non è abilitato nella configurazione server',
	"u_enoow": "non puoi sovrascrivere qui; serve permesso Elimina",
	"u_badf": 'Questi {0} file (di {1} totali) sono stati saltati, probabilmente a causa di permessi filesystem:\n\n',
	"u_blankf": 'Questi {0} file (di {1} totali) sono vuoti; caricarli comunque?\n\n',
	"u_applef": 'Questi {0} file (di {1} totali) sono probabilmente indesiderabili;\nPremi <code>OK/Invio</code> per SALTARE i seguenti file,\nPremi <code>Annulla/ESC</code> per NON escludere, e CARICARE anche quelli:\n\n',
	"u_just1": '\nForse funziona meglio se selezioni solo un file',
	"u_ff_many": "se stai usando <b>Linux / MacOS / Android,</b> allora questa quantità di file <a href=\"https://bugzilla.mozilla.org/show_bug.cgi?id=1790500\" target=\"_blank\"><em>potrebbe</em> far crashare Firefox!</a>\nse succede, riprova (o usa Chrome).",
	"u_up_life": "Questo caricamento sarà eliminato dal server\n{0} dopo che si completa",
	"u_asku": 'caricare questi {0} file in <code>{1}</code>',
	"u_unpt": "puoi annullare / eliminare questo caricamento usando 🧯 in alto a sinistra",
	"u_bigtab": 'sto per mostrare {0} file\n\nquesto potrebbe far crashare il tuo browser, sei sicuro?',
	"u_scan": 'Scansionando file...',
	"u_dirstuck": 'iteratore directory si è bloccato tentando di accedere ai seguenti {0} elementi; salterò:',
	"u_etadone": 'Fatto ({0}, {1} file)',
	"u_etaprep": '(preparando per caricare)',
	"u_hashdone": 'hashing completato',
	"u_hashing": 'hash',
	"u_hs": 'handshaking...',
	"u_started": "i file ora sono in caricamento; vedi [🚀]",
	"u_dupdefer": "duplicato; sarà processato dopo tutti gli altri file",
	"u_actx": "clicca questo testo per prevenire perdita di<br />prestazioni quando cambi ad altre finestre/schede",
	"u_fixed": "OK!&nbsp; Risolto 👍",
	"u_cuerr": "caricamento fallito del chunk {0} di {1};\nprobabilmente innocuo, continuo\n\nfile: {2}",
	"u_cuerr2": "il server ha rifiutato il caricamento (chunk {0} di {1});\nriproverò più tardi\n\nfile: {2}\n\nerrore ",
	"u_ehstmp": "riproverò; vedi in basso a destra",
	"u_ehsfin": "il server ha rifiutato la richiesta di finalizzare caricamento; riprovando...",
	"u_ehssrch": "il server ha rifiutato la richiesta di eseguire ricerca; riprovando...",
	"u_ehsinit": "il server ha rifiutato la richiesta di iniziare caricamento; riprovando...",
	"u_eneths": "errore di rete durante handshake per upload; riprovando...",
	"u_enethd": "errore di rete durante test esistenza target; riprovando...",
	"u_cbusy": "aspettando che il server si fidi di noi di nuovo dopo un problema di rete...",
	"u_ehsdf": "il server ha finito lo spazio su disco!\n\ncontinuerò a riprovare, nel caso qualcuno\nliberi abbastanza spazio per continuare",
	"u_emtleak1": "sembra che il tuo browser possa avere un memory leak;\nper favore",
	"u_emtleak2": ' <a href="{0}">passa a https (raccomandato)</a> o ',
	"u_emtleak3": ' ',
	"u_emtleakc": 'prova quanto segue:\n<ul><li>premi <code>F5</code> per aggiornare la pagina</li><li>poi disabilita il pulsante &nbsp;<code>mt</code>&nbsp; nelle &nbsp;<code>⚙️ impostazioni</code></li><li>e riprova quel caricamento</li></ul>I caricamenti saranno un po\' più lenti, ma pazienza.\nScusa per il disturbo !\n\nPS: chrome v107 <a href="https://bugs.chromium.org/p/chromium/issues/detail?id=1354816" target="_blank">ha un bugfix</a> per questo',
	"u_emtleakf": 'prova quanto segue:\n<ul><li>premi <code>F5</code> per aggiornare la pagina</li><li>poi abilita <code>🥔</code> (patata) nell\'UI caricamento<li>e riprova quel caricamento</li></ul>\nPS: firefox <a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank">avrà sperabilmente un bugfix</a> ad un certo punto',
	"u_s404": "non trovato sul server",
	"u_expl": "spiega",
	"u_maxconn": "la maggior parte dei browser limita questo a 6, ma firefox ti permette di alzarlo con <code>connections-per-server</code> in <code>about:config</code>",
	"u_tu": '<p class="warn">AVVISO: turbo abilitato, <span>&nbsp;client potrebbe non rilevare e riprendere caricamenti incompleti; vedi tooltip pulsante turbo</span></p>',
	"u_ts": '<p class="warn">AVVISO: turbo abilitato, <span>&nbsp;risultati ricerca possono essere incorretti; vedi tooltip pulsante turbo</span></p>',
	"u_turbo_c": "turbo è disabilitato nella configurazione server",
	"u_turbo_g": "disabilitando turbo perché non hai\nprivilegi di elenco directory all'interno di questo volume",
	"u_life_cfg": 'auto-elimina dopo <input id="lifem" p="60" /> min (o <input id="lifeh" p="3600" /> ore)',
	"u_life_est": 'caricamento sarà eliminato <span id="lifew" tt="ora locale">---</span>',
	"u_life_max": 'questa cartella impone una\nvita massima di {0}',
	"u_unp_ok": 'unpost è permesso per {0}',
	"u_unp_ng": 'unpost NON sarà permesso',
	"ue_ro": 'il tuo accesso a questa cartella è solo-Lettura\n\n',
	"ue_nl": 'attualmente non sei loggato',
	"ue_la": 'attualmente sei loggato come "{0}"',
	"ue_sr": 'attualmente sei in modalità file-search\n\npassa alla modalità upload cliccando la lente d\'ingrandimento 🔎 (accanto al grande pulsante CERCA), e prova a caricare di nuovo\n\nscusa',
	"ue_ta": 'prova a caricare di nuovo, dovrebbe funzionare ora',
	"ue_ab": "questo file è già in caricamento in un'altra cartella, e quel caricamento deve essere completato prima che il file possa essere caricato altrove.\n\nPuoi interrompere e dimenticare il caricamento iniziale usando l'🧯 in alto a sinistra",
	"ur_1uo": "OK: File caricato con successo",
	"ur_auo": "OK: Tutti i {0} file caricati con successo",
	"ur_1so": "OK: File trovato sul server",
	"ur_aso": "OK: Tutti i {0} file trovati sul server",
	"ur_1un": "Caricamento fallito, scusa",
	"ur_aun": "Tutti i {0} caricamenti falliti, scusa",
	"ur_1sn": "File NON trovato sul server",
	"ur_asn": "I {0} file NON sono stati trovati sul server",
	"ur_um": "Finito;\n{0} caricamenti OK,\n{1} caricamenti falliti, scusa",
	"ur_sm": "Finito;\n{0} file trovati sul server,\n{1} file NON trovati sul server",

	"rc_opn": "apri", //m
	"rc_ply": "riproduci", //m
	"rc_pla": "riproduci come audio", //m
	"rc_txt": "apri nel visualizzatore di file", //m
	"rc_md": "apri nell’editor di testo", //m
	"rc_dl": "scarica", //m
	"rc_zip": "scarica come archivio", //m
	"rc_cpl": "copia link", //m
	"rc_del": "elimina", //m
	"rc_cut": "taglia", //m
	"rc_cpy": "copia", //m
	"rc_pst": "incolla", //m
	"rc_rnm": "rinomina", //m
	"rc_nfo": "nuova cartella", //m
	"rc_nfi": "nuovo file", //m
	"rc_sal": "seleziona tutto", //m
	"rc_sin": "inverti selezione", //m
	"rc_shf": "condividi questa cartella", //m
	"rc_shs": "condividi selezione", //m

	"lang_set": "aggiornare per rendere effettivo il cambiamento?",

	"splash": {
		"a1": "aggiorna",
		"b1": "ciao &nbsp; <small>(non sei connesso)</small>",
		"c1": "disconnetti",
		"d1": "stato",
		"d2": "mostra lo stato di tutti i thread attivi",
		"e1": "ricarica configurazione",
		"e2": "ricarica i file di configurazione (account/volumi/flag dei volumi),\n e riesegue la scansione di tutti i volumi e2ds.\n\nNota: qualsiasi modifica alle impostazioni globali richiede un riavvio completo per avere effetto",
		"f1": "puoi visualizzare:",
		"g1": "puoi caricare su:",
		"cc1": "altro:",
		"h1": "disattiva k304",
		"i1": "attiva k304",
		"j1": "k304 interrompe la connessione per ogni HTTP 304. Questo aiuta contro alcuni proxy difettosi che possono bloccarsi o smettere improvvisamente di caricare pagine, ma riduce notevolmente le prestazioni",
		"k1": "resetta impostazioni",
		"l1": "accedi:",
		"ls3": "accedi", //m
		"lu4": "nome utente", //m
		"lp4": "password", //m
		"lo3": "disconnetti “{0}” ovunque", //m
		"lo2": "questo terminerà la sessione su tutti i browser", //m
		"m1": "bentornato,",
		"n1": "404: file non trovato &nbsp;┐( ´ -`)┌",
		"o1": "oppure forse non hai accesso? prova una password o <a href=\"SR/?h\">torna alla home</a>",
		"p1": "403: accesso negato &nbsp;~┻━┻",
		"q1": "prova una password o <a href=\"SR/?h\">torna alla home</a>",
		"r1": "torna alla home",
		".s1": "mappa",
		"t1": "azione",
		"u2": "tempo dall'ultima scrittura sul server\n (caricamento / rinomina / ...)\n\n17d = 17 giorni\n1h23 = 1 ora 23 minuti\n4m56 = 4 minuti 56 secondi",
		"v1": "connetti",
		"v2": "usa questo server come un disco locale",
		"w1": "passa a https",
		"x1": "cambia password",
		"y1": "le tue condivisioni",
		"z1": "sblocca area:",
		"ta1": "devi prima inserire una nuova password",
		"ta2": "ripeti per confermare la nuova password:",
		"ta3": "errore di digitazione; riprova",
		"nop": "ERRORE: La password non può essere vuota", //m
		"nou": "ERRORE: Il nome utente e/o la password non possono essere vuoti", //m
		"aa1": "in arrivo:",
		"ab1": "disattiva no304",
		"ac1": "attiva no304",
		"ad1": "no304 disabilita completamente la cache. Se k304 non è sufficiente, prova questa opzione. Aumenterà notevolmente il consumo di dati!",
		"ae1": "in uscita:",
		"af1": "mostra i file caricati di recente",
		"ag1": "mostra utenti IdP conosciuti",
	}
};
